%define majver %(echo %version | sed "s|[a-z]||")
Name:          libgc
Epoch:         1
Version:       8.2.8
Release:       1mamba
Summary:       Boehm Conservative Garbage Collection for C/C++
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.hboehm.info/gc/
Source:        https://github.com/ivmai/bdwgc.git/v%{version}/bdwgc-%{version}.tar.bz2
#Source:        http://www.hboehm.info/gc/gc_source/gc-%{version}.tar.gz
Patch0:        libgc-7.1-dup_cpp_headers.patch
Patch1:        libgc-7.2alpha4-install_dups.patch
License:       BSD 
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END
BuildRequires: libatomic_ops-devel
BuildRequires: libtool

%description
This is a garbage collecting storage allocator that is intended to be used as a plug-in replacement for C's malloc.

Since the collector does not require pointers to be tagged, it does not attempt to ensure that all inaccessible storage is reclaimed. However, in our experience, it is typically more successful at reclaiming unused memory than most C programs using explicit deallocation. Unlike manually introduced leaks, the amount of unreclaimed memory typically stays bounded.

%package devel
Group:         Development/Libraries
Summary:       Static libraries and headers for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
This is a garbage collecting storage allocator that is intended to be used as a plug-in replacement for C's malloc.
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q -n bdwgc-%{version}
#%patch0 -p1
#%patch1 -p1
rm -f libtool libtool.m4
autoreconf -i

%build
%configure \
   --prefix=%{_prefix} \
   --disable-dependency-tracking \
   --disable-static \
   --enable-cplusplus \
   --enable-large-config \
%ifarch %{ix86} x86_64
   --enable-parallel-mark \
%endif
   --enable-threads=posix \
   --with-libatomic-ops=external

%make
#% make -C libatomic_ops

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%makeinstall DESTDIR=%{buildroot}

mkdir -p %{buildroot}%{_mandir}/man3
install -pm 644 doc/gc.man %{buildroot}%{_mandir}/man3/gc.3

rm -rf %{buildroot}%{_datadir}/gc/

%ifnarch arm
%check
make check
%endif

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}


%files
%defattr(-,root,root)
%{_libdir}/libgc.so.*
%{_libdir}/libcord.so.*
%{_libdir}/libgccpp.so.*
%{_libdir}/libgctba.so.*
 %doc AUTHORS
 
%files devel
%defattr(-,root,root)
%{_includedir}/*.h
%{_includedir}/gc/*.h
%{_libdir}/libgc.so
%{_libdir}/libcord.so
%{_libdir}/libgccpp.so
%{_libdir}/libgctba.so
%{_libdir}/pkgconfig/bdw-gc.pc
%{_mandir}/man3
%dir %{_datadir}/doc/gc/
%{_datadir}/doc/gc/*
%doc doc/README*

%changelog
* Mon Sep 09 2024 Automatic Build System <autodist@openmamba.org> 8.2.8-1mamba
- automatic version update by autodist

* Mon Feb 05 2024 Automatic Build System <autodist@openmamba.org> 8.2.6-1mamba
- automatic version update by autodist

* Tue May 30 2023 Automatic Build System <autodist@mambasoft.it> 8.2.4-1mamba
- automatic version update by autodist

* Sat Aug 27 2022 Automatic Build System <autodist@mambasoft.it> 8.2.2-1mamba
- automatic version update by autodist

* Fri Oct 15 2021 Automatic Build System <autodist@mambasoft.it> 8.2.0-1mamba
- automatic version update by autodist

* Thu Sep 30 2021 Automatic Build System <autodist@mambasoft.it> 8.0.6-1mamba
- automatic version update by autodist

* Thu Sep 26 2019 Automatic Build System <autodist@mambasoft.it> 8.0.4-1mamba
- automatic version update by autodist

* Tue Sep 04 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 7.6.8-1mamba
- update to 7.6.8

* Sat Mar 24 2018 Automatic Build System <autodist@mambasoft.it> 7.6.4-1mamba
- automatic version update by autodist

* Sun Sep 18 2016 Automatic Build System <autodist@mambasoft.it> 7.6.0-1mamba
- automatic update by autodist

* Sun Aug 07 2016 Automatic Build System <autodist@mambasoft.it> 7.4.4-1mamba
- automatic update by autodist

* Tue Jun 17 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 7.4.2-1mamba
- update to 7.4.2

* Tue Nov 26 2013 Automatic Build System <autodist@mambasoft.it> 7.4.0-1mamba
- automatic update by autodist

* Sun Dec 09 2012 Automatic Build System <autodist@mambasoft.it> 7.2d-1mamba
- update to 7.2d

* Sun Aug 19 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 7.2-1mamba
- update to 7.2

* Sun Jul 24 2011 Automatic Build System <autodist@mambasoft.it> 7.2alpha6-1mamba
- automatic version update by autodist

* Sun Dec 26 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 7.2alpha4-3mamba
- automatic port from devel-java

* Sat Dec 04 2010 gil <puntogil@libero.it> 7.2alpha4-2mamba
- rebuilt devel

* Sun May 02 2010 gil <puntogil@libero.it> 7.2alpha4-1mamba
- update to 7.2alpha4

* Sat May 31 2008 gil <puntogil@libero.it> 7.1-1mamba
- update to 7.1
- edit URL

* Thu Mar 03 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 6.4-1qilnx
- update to version 6.4 by autospec

* Fri Dec 03 2004 Davide Madrisan <davide.madrisan@qilinux.it> 6.3-1qilnx
- package created by autospec
